@@ -34,7 +34,34 @@ nlmixr2est::nmObjGetControl
 #' @export
 nonmem2rx::nonmem2rx
 
+#' @importFrom nonmem2rx nmcov
+#' @export
+nonmem2rx::nmcov
+
+#' @importFrom nonmem2rx nmext
+#' @export
+nonmem2rx::nmext
+
+#' @importFrom nonmem2rx nminfo
+#' @export
+nonmem2rx::nminfo
+
+#' @importFrom nonmem2rx nmtab
+#' @export
+nonmem2rx::nmtab
+
+#' @importFrom nonmem2rx nmxml
+#' @export
+nonmem2rx::nmxml
+
 #' @importFrom nonmem2rx as.nonmem2rx
 #' @export
 nonmem2rx::as.nonmem2rx
 
+#' @importFrom monolix2rx monolix2rx
+#' @export
+monolix2rx::monolix2rx
+
+#' @importFrom monolix2rx mlxtran
+#' @export
+monolix2rx::mlxtran
